package cn.com.ty.lift.business.library.service;

import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.library.dao.entity.Lift;
import cn.com.ty.lift.business.library.dao.entity.ProjectLiftRelevance;
import cn.com.ty.lift.business.library.dao.entity.model.BatchUpdateLiftRequest;
import cn.com.ty.lift.business.library.dao.entity.model.LiftExtensionRequest;
import cn.com.ty.lift.business.library.dao.mapper.ProjectLiftRelevanceMapper;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * @author bieao
 * @date 2019/12/5
 * @description 项目电梯关联业务层
 */
@Service
public class ProjectLiftRelevanceService extends ServiceImpl<ProjectLiftRelevanceMapper, ProjectLiftRelevance> {

    /**
     * @param entry 项目关联数据
     * @return RestResponse 状态码和返回消息
     * @description 逻辑删除电梯
     * @date 2019/12/5 2:16 PM
     */
    public RestResponse logicDelete(ProjectLiftRelevance entry) {
        boolean result = updateById(entry);
        if (!result) {
            return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.fail"));
        }
        return RestResponse.ok(ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.modify.success"));
    }

    /**
     * @param request 电梯扩展请求
     * @param id        平台企业电梯主键id
     * @param workerId  维保工id
     * @return projectLiftEntry
     * @description 新增项目电梯关联数据
     * @date 2019/12/5 2:39 PM
     */
    public boolean save(LiftExtensionRequest request, long id, long workerId) {
        Lift lift = request.getLift();
        //新增项目电梯关联表
        ProjectLiftRelevance projectLiftEntry = new ProjectLiftRelevance();
        projectLiftEntry.setProjectId(request.getProjectId());
        projectLiftEntry.setLiftId(lift.getId());
        projectLiftEntry.setRelevanceId(id);
        projectLiftEntry.setWorkerId(workerId);
        projectLiftEntry.setCompanyId(request.getMtCompanyId());
        return save(projectLiftEntry);
    }

    /**
     * @param request
     * @return RestResponse 状态码和返回消息
     * @description 项目锁定、解锁,锁定该项目下的电梯
     * @date 2019/12/5 11:00 AM
     */
    @Transactional
    public RestResponse lockOrUnlock(BatchUpdateLiftRequest request) {
        String source = request.getOperate();
        switch (source) {
            //锁定电梯
            case "0":
                boolean result = updateBatchById(request.getUpdateLiftList());
                if (!result) {
                    return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.fail"));
                }
                break;
            //锁定项目
            case "1":
                boolean ret = updateById(request.getUpdateLiftList().get(0));
                if (!ret){
                    return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.fail"));
                }
                boolean response = updateBatchById(request.getUpdateLiftList());
                if (!response){
                    return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.fail"));
                }
                break;
            default:
                break;
        }
        return RestResponse.ok(ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.modify.success"));
    }
}
