package cn.com.ty.lift.enterprise.custom.controller;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyContact;
import cn.com.ty.lift.enterprise.custom.dao.entity.model.PropertyContactReq;
import cn.com.ty.lift.enterprise.custom.service.PropertyCompanyService;
import cn.com.ty.lift.enterprise.custom.service.impl.PropertyContactServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/property-contact")
@AllArgsConstructor
/**
 * @author wang-hai-cheng
 * @date 2019/11/27
 * @description
 * (甲方联系人)客户联系人表 前端控制器
 */
public class PropertyContactController {
    private final PropertyContactServiceImpl propertyContactService;
    private final PropertyCompanyService propertyCompanyService;

    @PostMapping("/list")
    /**
     * @description 根据客户id分页查它的联系人
     * @date 2019/11/29 8:21
     * @param [ppCompanyId, pageNum, pageSize]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyContacts(@RequestBody PropertyContactReq propertyContact) {
        if (propertyCompanyService.getById(propertyContact.getPpCompanyId()) == null) {
            return RestResponse.ok(null, "0", "客户不存在");
        }
        Page<PropertyContact> page = new Page<>(propertyContact.getPageNum(), propertyContact.getPageSize());
        IPage<PropertyContact> records = propertyContactService.page(page, new QueryWrapper<PropertyContact>()
                .select("id", "pp_company_id", "name", "job", "telephone", "status")
                .ne("status", 0)
                .eq("pp_company_id", propertyContact.getPpCompanyId())
        );
        if (records.getRecords().isEmpty()) {
            return RestResponse.ok(null, "9", "无数据");
        }
        return RestResponse.ok(records, "1", "查询成功");
    }

    @PostMapping("/add")
    /**
     * @description 根据客户id，新增联系人
     * @date 2019/11/27 11:23
     * @param [propertyContact]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse add(@RequestBody PropertyContact propertyContact) {
        if (propertyCompanyService.getById(propertyContact.getPpCompanyId()) == null) {
            return RestResponse.ok(null, "0", "客户不存在");
        }
        if (propertyContactService.save(propertyContact)) {
            return RestResponse.ok(propertyContact.getId(), "1", "新增成功");
        }
        return RestResponse.ok(null, "0", "新增失败");
    }

    @PostMapping("/update")
    /**
     * @description 编辑联系人
     * @date 2019/11/27 11:26
     * @param [propertyContact]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse update(@RequestBody PropertyContact propertyContact) {
        if (propertyContactService.updateById(propertyContact)) {
            return RestResponse.ok(null, "1", "更新成功");
        }
        return RestResponse.ok(null, "0", "更新失败");
    }

    @PostMapping("/delete")
    /**
     * @description 删除联系人
     * @date 2019/11/27 11:28
     * @param [id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse delete(@RequestBody PropertyContact propertyContact) {
        return propertyContactService.delete(propertyContact.getId());
    }

    @PostMapping("/project/contacts")
    public RestResponse customs(@RequestBody PropertyContact propertyContact) {
        List<PropertyContact> propertyCompanies = propertyContactService.list(new QueryWrapper<PropertyContact>()
                .select("id", "name", "telephone")
                .ne("status", 0)
                .eq("pp_company_id", propertyContact.getPpCompanyId()));
        if (propertyCompanies.isEmpty()) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, "无数据");
        }
        return RestResponse.ok(propertyCompanies, ApiConstants.RESULT_SUCCESS, "查询成功");
    }

    /**
     * @description 项目模块，新增客户联系人
     * @date 2019/12/16 17:09
     */
    @PostMapping("/project/contact/add")
    public RestResponse customAdd(@RequestBody PropertyContact propertyContact) {
        propertyContact.setStatus(2);
        if (propertyContactService.save(propertyContact)) {
            return RestResponse.ok(propertyContact.getId(), ApiConstants.RESULT_SUCCESS, "新增成功");
        }
        return RestResponse.ok(null, ApiConstants.RESULT_ERROR, "新增失败");
    }
}